@@ -23,7 +23,6 @@ import yum.Errors
 
 from utils import YumUtilBase
 from yum import _
-from yum.i18n import to_unicode
 
 import logging
 import rpmUtils
@@ -45,7 +44,7 @@ class DebugInfoInstall(YumUtilBase):
                              DebugInfoInstall.USAGE)
         self.logger = logging.getLogger("yum.verbose.cli.debuginfoinstall")
         self.optparser = self.getOptionParser()
-        opt = self.optparser
+        opts = self.optparser
         # Add util commandline options to the yum-cli ones
         if hasattr(self, 'getOptionGroup'):
             opts = self.getOptionGroup()
@@ -77,28 +76,39 @@ class DebugInfoInstall(YumUtilBase):
             self.logger.critical("Another application is holding the yum lock, cannot continue")
             sys.exit(1)
         
-        
-        # Setup yum (Ts, RPM db, Repo & Sack)
-        self.doUtilYumSetup()
-        
         # enable the -debuginfo repos for enabled primary repos
+        repos = {}
         for repo in self.repos.listEnabled():
-            di = '%s-debuginfo' % repo.id
+            repos[repo.id] = repo
+        for repoid in repos:
+            di = '%s-debuginfo' % repoid
+            if di in repos:
+                continue
+            repo = repos[repoid]
             for r in self.repos.findRepos(di):
                 self.logger.log(yum.logginglevels.INFO_2, 
                                 _('enabling %s') % r.id)
                 r.enable()
-                try:
-                    self.doRepoSetup(thisrepo=r.id)
-                except yum.Errors.RepoError, e:
-                    self.logger.critical("Could not access repo %s error was: %s" %
-                                        (r.id, to_unicode(str(e))))
-                    sys.exit(1)
-                         
-                #r.setup(self.conf.cache, self.mediagrabber)
+                # Note: This is shared with auto-update-debuginfo
+                for opt in ['repo_gpgcheck', 'gpgcheck', 'cost',
+                            'skip_if_unavailable']:
+                    if hasattr(r, opt):
+                        setattr(r, opt, getattr(repo, opt))
+
+        # Setup yum (Ts, RPM db, Repo & Sack)
+        self.doUtilYumSetup()
         
         self.debugInfo_main()
-        self.buildTransaction()
+        if hasattr(self, 'doUtilBuildTransaction'):
+            errc = self.doUtilBuildTransaction()
+            if errc:
+                sys.exit(errc)
+        else:
+            try:
+                self.buildTransaction()
+            except yum.Errors.YumBaseError, e:
+                self.logger.critical("Error building transaction: %s" % e)
+                sys.exit(1)
         if len(self.tsInfo) < 1:
             print 'No debuginfo packages available to install'
             self.doUnlock()
