@@ -31,6 +31,7 @@ import os
 import re
 import yum.depsolve # For flags
 
+from yum.Errors import YumBaseError
 from rpmUtils import miscutils, arch
 from optparse import OptionGroup
 
@@ -92,7 +93,7 @@ class PackageCleanup(YumUtilBase):
                     help='list all packages leaf nodes that do not match'\
                          ' leaf-regex')
         leafgrp.add_option("--leaf-regex", 
-                    default="(^(compat-)?lib.+|.*libs?[\d-]*$)",
+                    default="(^(compat-)?lib(?!reoffice).+|.*libs?[\d-]*|.*-data$)",
                     help='A package name that matches this regular expression' \
                          ' (case insensitively) is a leaf')
         leafgrp.add_option("--exclude-devel", default=False, 
@@ -129,7 +130,7 @@ class PackageCleanup(YumUtilBase):
             for (req,flags,ver)  in po.requires:
                     
                 if req.startswith('rpmlib'): continue # ignore rpmlib deps
-                if not providers.has_key((req,flags,ver)):
+                if (req,flags,ver) not in providers:
                     resolve_sack = self.rpmdb.whatProvides(req,flags,ver)
                 else:
                     resolve_sack = providers[(req,flags,ver)]
@@ -270,7 +271,12 @@ class PackageCleanup(YumUtilBase):
         runningkernel = os.uname()[2]
         # Vanilla kernels dont have a release, only a version
         if '-' in runningkernel:
-            (kver,krel) = runningkernel.split('-')
+            splt = runningkernel.split('-')
+            if len(splt) == 2:
+                (kver,krel) = splt
+            else: # Handle cases where a custom build kernel has an extra '-' in the release
+                kver=splt[1]
+                krel="-".join(splt[1:])
             if krel.split('.')[-1] == os.uname()[-1]:
                 krel = ".".join(krel.split('.')[:-1])
         else:
@@ -335,7 +341,18 @@ class PackageCleanup(YumUtilBase):
                 sys.exit(100)
                 
             self._remove_old_kernels(opts.kernelcount, opts.keepdevel)
-            self.buildTransaction()
+            self.run_with_package_names.add('yum-utils')
+            if hasattr(self, 'doUtilBuildTransaction'):
+                errc = self.doUtilBuildTransaction()
+                if errc:
+                    sys.exit(errc)
+            else:
+                try:
+                    self.buildTransaction()
+                except yum.Errors.YumBaseError, e:
+                    self.logger.critical("Error building transaction: %s" % e)
+                    sys.exit(1)
+
             if len(self.tsInfo) < 1:
                 print 'No old kernels to remove'
                 sys.exit(0)
@@ -358,9 +375,12 @@ class PackageCleanup(YumUtilBase):
             if not self.setCacheDir():
                 self.logger.error("Error: Could not make cachedir, exiting")
                 sys.exit(50)
-            
-            for po in sorted(self.doPackageLists(pkgnarrow='extras').extras):
-                print po.hdr.sprintf(opts.qf)
+            try:
+                for po in sorted(self.doPackageLists(pkgnarrow='extras').extras):
+                    print po.hdr.sprintf(opts.qf)
+            except YumBaseError,e:
+                self.logger.error("Error: %s" % str(e))
+                sys.exit(1)                
             sys.exit(0)
 
 
@@ -371,7 +391,20 @@ class PackageCleanup(YumUtilBase):
             if opts.noscripts:
                 self.conf.tsflags.append('noscripts')
             self._remove_old_dupes()
-            self.buildTransaction()
+            self.run_with_package_names.add('yum-utils')
+
+            if hasattr(self, 'doUtilBuildTransaction'):
+                errc = self.doUtilBuildTransaction()
+                if errc:
+                    sys.exit(errc)
+            else:
+                try:
+                    self.buildTransaction()
+                except yum.Errors.YumBaseError, e:
+                    self.logger.critical("Error building transaction: %s" % e)
+                    sys.exit(1)
+                                    
+
             if len(self.tsInfo) < 1:
                 print 'No duplicates to remove'
                 sys.exit(0)
