@@ -58,7 +58,7 @@ def srpmname(pkg):
 def _show_changes_changelog(conduit, srpms):
     for name in sorted(srpms.keys()):
         rpms = []
-        if origpkgs.has_key(name):
+        if name in origpkgs:
             for rpm in srpms[name]:
                 rpms.append("%s" % rpm)
             done = False
@@ -85,7 +85,7 @@ def show_changes(conduit, msg):
         if not tsmem.updates:
             continue
         name = srpmname(tsmem.po)
-        if srpms.has_key(name):
+        if name in srpms:
             srpms[name].append(tsmem.po)
         else:
             srpms[name] = [tsmem.po]
@@ -163,7 +163,7 @@ Display changelog data, since a specified time, on a group of packages"""
                     self._done_spkgs[pkg.sourcerpm] = True
                     msg('%-40.40s %s' % (pkg, pkg.repoid))
                 self._changelogs += 1
-                msg(line)
+                msg(to_unicode(line))
                 msg('')
 
     def doCommand(self, base, basecmd, extcmds):
@@ -283,7 +283,7 @@ def postresolve_hook(conduit):
         mdi = UpdateMetadata(repos=list(repos))
     for tsmem in ts.getMembers():
         for po in rpmdb.searchNevra(name=tsmem.po.name, arch=tsmem.po.arch):
-            times = po.hdr['changelogtime']
+            times = po['changelogtime']
             try:
                 n,v,r,e,a = splitFilename(po.sourcerpm)
             except TypeError:
