@@ -41,7 +41,6 @@ import os
 import sys
 import time
 import socket
-import string
 import urlparse
 import datetime
 import asyncore
@@ -135,7 +134,7 @@ def postreposetup_hook(conduit):
     repomirrors = {}
     repos = conduit.getRepos()
     for repo in repos.listEnabled():
-        if not repomirrors.has_key(str(repo)):
+        if str(repo) not in repomirrors:
             repomirrors[str(repo)] = FastestMirror(repo.urls).get_mirrorlist()
         if exclude:
             for mirror in repomirrors[str(repo)]:
