@@ -39,7 +39,7 @@ def parseArgs():
     dependencies in all packages for resolution. Print out the list of
     packages with unresolved dependencies
     
-    %s [-c <config file>] [-a <arch>] [-r <repoid>] [-r <repoid2>]
+    %s [-c <config file>] [-a <arch>] [-l <lookaside>] [-r <repoid>] [-r <repoid2>]
     """ % sys.argv[0]
     parser = OptionParser(usage=usage)
     parser.add_option("-c", "--config", default='/etc/yum.conf',
@@ -51,6 +51,8 @@ def parseArgs():
                       help="set the basearch for yum to run as")
     parser.add_option("-b", "--builddeps", default=False, action="store_true",
         help='check build dependencies only (needs source repos enabled)')
+    parser.add_option("-l", "--lookaside", default=[], action='append',
+        help="specify a lookaside repo id to query, can be specified multiple times")
     parser.add_option("-r", "--repoid", default=[], action='append',
         help="specify repo ids to query, can be specified multiple times (default is all enabled)")
     parser.add_option("-t", "--tempcache", default=False, action="store_true", 
@@ -60,9 +62,11 @@ def parseArgs():
     parser.add_option("-n", "--newest", default=0, action="store_true",
                       help="check only the newest packages in the repos")
     parser.add_option("--repofrompath", action="append",
-                      help="specify repoid & paths of additional repositories - unique repoid and complete path required, can be specified multiple times. Example. --repofrompath=myrepo,/path/to/repo")
+                      help="specify repoid & paths of additional repositories - unique repoid and path required, can be specified multiple times. Example. --repofrompath=myrepo,/path/to/repo")
     parser.add_option("-p", "--pkg", action="append",
                       help="check closure for this package only")
+    parser.add_option("-g", "--group", action="append",
+                      help="check closure for packages in this group only")
     (opts, args) = parser.parse_args()
     return (opts, args)
 
@@ -70,13 +74,15 @@ def parseArgs():
 # so we have to do at least some API guarantee stuff.
 class RepoClosure(yum.YumBase):
     def __init__(self, arch=[], config="/etc/yum.conf", builddeps=False, pkgonly=None,
-                 basearch=None):
+                 basearch=None, grouponly=None):
         yum.YumBase.__init__(self)
         if basearch:
             self.preconf.arch = basearch
         self.logger = logging.getLogger("yum.verbose.repoclosure")
+        self.lookaside = []
         self.builddeps = builddeps
         self.pkgonly = pkgonly
+        self.grouponly = grouponly
         self.doConfigSetup(fn = config,init_plugins=False)
         self._rc_arches = arch
 
@@ -85,10 +91,10 @@ class RepoClosure(yum.YumBase):
             self.repos._selectSackType()
     
     def evrTupletoVer(self,tup):
-        """convert and evr tuple to a version string, return None if nothing
+        """convert an evr tuple to a version string, return None if nothing
         to convert"""
     
-        e, v,r = tup
+        e, v, r = tup
 
         if v is None:
             return None
@@ -145,23 +151,39 @@ class RepoClosure(yum.YumBase):
         if self.builddeps:
             pkgs = filter(lambda x: x.arch == 'src', pkgs)
 
-        if self.pkgonly:
-            pkgs = filter(lambda x: x.name == self.pkgonly[0], pkgs)
+        pkglist = self.pkgonly
+        if self.grouponly:
+            if not pkglist:
+                pkglist = []
+            for group in self.grouponly:
+                groupobj = self.comps.return_group(group)
+                if not groupobj:
+                    continue
+                pkglist.extend(groupobj.packages)
+
+        if pkglist:
+            pkgs = filter(lambda x: x.name in pkglist, pkgs)
 
         for pkg in pkgs:
+            if pkg.repoid in self.lookaside:
+                # don't attempt to resolve dependancy issues for
+                # packages from lookaside repositories
+                continue
             for (req, flags, (reqe, reqv, reqr)) in pkg.returnPrco('requires'):
                 if req.startswith('rpmlib'): continue # ignore rpmlib deps
             
                 ver = self.evrTupletoVer((reqe, reqv, reqr))
-                if resolved.has_key((req,flags,ver)):
+                if (req,flags,ver) in resolved:
                     continue
+                
+                resolve_sack = [] # make it empty
                 try:
                     resolve_sack = self.whatProvides(req, flags, ver)
                 except yum.Errors.RepoError, e:
                     pass
             
                 if len(resolve_sack) < 1:
-                    if not unresolved.has_key(pkg):
+                    if pkg not in unresolved:
                         unresolved[pkg] = []
                     unresolved[pkg].append((req, flags, ver))
                     continue
@@ -176,9 +198,9 @@ class RepoClosure(yum.YumBase):
                     if resolved_by_newest:                    
                         resolved[(req,flags,ver)] = 1
                     else:
-                        if not unresolved.has_key(pkg):
+                        if pkg not in unresolved:
                             unresolved[pkg] = []
-                        unresolved[pkg].append((req, flags, ver))                        
+                        unresolved[pkg].append((req, flags, ver))
                         
         return unresolved
     
@@ -189,18 +211,19 @@ def main():
                      config=opts.config, 
                      builddeps=opts.builddeps,
                      pkgonly=opts.pkg,
+                     grouponly=opts.group,
                      basearch=opts.basearch)
 
     if opts.repofrompath:
         # setup the fake repos
         for repo in opts.repofrompath:
             repoid,repopath = tuple(repo.split(','))
-            if repopath[0] == '/':
-                baseurl = 'file://' + repopath
-            else:
+            if repopath.startswith('http') or repopath.startswith('ftp') or repopath.startswith('file:'):
                 baseurl = repopath
+            else:
+                repopath = os.path.abspath(repopath)                
+                baseurl = 'file://' + repopath
                 
-            repopath = os.path.normpath(repopath)
             newrepo = yum.yumRepo.YumRepository(repoid)
             newrepo.name = repopath
             newrepo.baseurl = baseurl
@@ -213,11 +236,15 @@ def main():
     
     if opts.repoid:
         for repo in my.repos.repos.values():
-            if repo.id not in opts.repoid:
+            if ((repo.id not in opts.repoid) and
+                (repo.id not in opts.lookaside)):
                 repo.disable()
             else:
                 repo.enable()
 
+    if opts.lookaside:
+        my.lookaside = opts.lookaside
+
     if os.geteuid() != 0 or opts.tempcache:
         cachedir = getCacheDir()
         if cachedir is None:
@@ -273,5 +300,10 @@ def main():
             my.logger.info('     %s' % req)
 
 if __name__ == "__main__":
-    main()
+    try:
+        main()
+    except (yum.Errors.YumBaseError, ValueError), e:
+        print >> sys.stderr, str(e)
+        sys.exit(1)
+        
         
