@@ -19,6 +19,7 @@ import sys
 import datetime
 import os
 import locale
+import rpmUtils.arch
 from yum.i18n import to_unicode
 
 from optparse import OptionParser
@@ -52,49 +53,78 @@ class DiffYum(yum.YumBase):
         self.repos.enableRepo(repoid)
         # setup the repo dirs/etc
         self.doRepoSetup(thisrepo=repoid)
-        self._getSacks(archlist=self.dy_archlist, thisrepo=repoid)
+        if '*' in self.dy_archlist:
+            # Include all known arches
+            arches = rpmUtils.arch.arches
+            archlist = list(set(arches.keys()).union(set(arches.values())))
+        else:
+            archlist = self.dy_archlist
+        self._getSacks(archlist=archlist, thisrepo=repoid)
 
-    def dy_diff(self):
+    def dy_diff(self, compare_arch=False):
         add = []
         remove = []        
         modified = []
         obsoleted = {} # obsoleted = by
-        newsack = yum.packageSack.ListPackageSack()
-        for repoid in self.dy_repos['new']:
-            newsack.addList(self.pkgSack.returnPackages(repoid=repoid))
 
-        oldsack = yum.packageSack.ListPackageSack()
-        for repoid in self.dy_repos['old']:
-            oldsack.addList(self.pkgSack.returnPackages(repoid=repoid))
-
-        for pkg in newsack.returnNewestByName():
-            tot = self.pkgSack.searchNevra(name=pkg.name)
-            if len(tot) == 1: # it's only in new
-                add.append(pkg)
-            if len(tot) > 1:
-                if oldsack.contains(name=pkg.name):
-                    newest_old = oldsack.returnNewestByName(name=pkg.name)[0]
-                    if newest_old.EVR != pkg.EVR:
-                        modified.append((pkg, newest_old))
+        #  Originally we did this by setting up old and new repos. ... but as
+        # a faster way, we can just go through all the pkgs once getting the
+        # newest pkg with a repoid prefix of "old", dito. "new", and then
+        # compare those directly.
+        def _next_old_new(pkgs):
+            """ Returns latest pair of (oldpkg, newpkg) for each package
+                name. If that name doesn't exist, then it returns None for
+                that package. """
+            last = None
+            npkg = opkg = None
+            for pkg in sorted(pkgs):
+                if compare_arch:
+                    key = (pkg.name, pkg.arch)
                 else:
-                    add.append(pkg)
+                    key = pkg.name
 
-        for pkg in oldsack.returnNewestByName():
-            if len(newsack.searchNevra(name=pkg.name)) == 0:
-                remove.append(pkg)
+                if last is None:
+                    last = key
+                if last != key:
+                    yield opkg, npkg
+                    opkg = npkg = None
+                    last = key
 
+                if pkg.repo.id.startswith('old'):
+                    opkg = pkg
+                else:
+                    assert pkg.repo.id.startswith('new')
+                    npkg = pkg
+            if opkg is not None or npkg is not None: 
+                yield opkg, npkg
 
+        for opkg, npkg in _next_old_new(self.pkgSack.returnPackages()):
+            if opkg is None:
+                add.append(npkg)
+            elif npkg is None:
+                remove.append(opkg)
+            elif not npkg.verEQ(opkg):
+                modified.append((npkg, opkg))
+
+        ao = {}
+        for pkg in add:
+            for obs_name in set(pkg.obsoletes_names):
+                if obs_name not in ao:
+                    ao[obs_name] = []
+                ao[obs_name].append(pkg)
+
+        #  Note that this _only_ shows something when you have an additional
+        # package obsoleting a removed package. If the obsoleted package is
+        # still there (somewhat "common") or the obsoleter is an update (dito)
+        # you _don't_ get hits here.
         for po in remove:
-            for newpo in add:
-                foundit = 0
-                for obs in newpo.obsoletes:
-                    if po.inPrcoRange('provides', obs):
-                        foundit = 1
-                        obsoleted[po] = newpo
-                        break
-                if foundit:
+            # Remember: Obsoletes are for package names only.
+            poprovtup = (po.name, 'EQ', (po.epoch, po.ver, po.release))
+            for newpo in ao.get(po.name, []):
+                if newpo.inPrcoRange('obsoletes', poprovtup):
+                    obsoleted[po] = newpo
                     break
-        
+
         ygh = yum.misc.GenericHolder()
         ygh.add = add
         ygh.remove = remove
@@ -123,8 +153,12 @@ def parseArgs(args):
     parser.add_option("-q", "--quiet", default=False, action='store_true')
     parser.add_option("-a", "--archlist", default=[], action="append",
                       help="In addition to src.rpms, any arch you want to include")
+    parser.add_option("--compare-arch", default=False, action='store_true',
+                      help="When comparing binary repos. also compare the arch of packages, to see if they are different")
     parser.add_option("-s", "--size", default=False, action='store_true',
                       help="Output size changes for any new->old packages")
+    parser.add_option("--simple",  default=False, action='store_true',
+                      help="output simple format")
     (opts, argsleft) = parser.parse_args()
 
     if not opts.new or not opts.old:
@@ -132,10 +166,12 @@ def parseArgs(args):
         sys.exit(1)
 
     # sort out the comma-separated crap we somehow inherited.    
-    archlist = ['src']
+    archlist = []
     for a in opts.archlist:
         for arch in a.split(','):
             archlist.append(arch)
+    if not archlist :
+        archlist = ['src']
 
     opts.archlist = archlist             
     
@@ -146,12 +182,21 @@ def main(args):
 
             
     my = DiffYum()
+    archlist_changed = False
+    if opts.archlist and not opts.archlist[0] == 'src':
+        my.preconf.arch = opts.archlist[0]
+        archlist_changed = True
+
     if opts.quiet:
         my.conf.debuglevel=0
         my.doLoggingSetup(my.conf.debuglevel, my.conf.errorlevel)
     
+    my.conf.disable_excludes = ['all']
     my.dy_shutdown_all_other_repos()
     my.dy_archlist = opts.archlist
+    if archlist_changed:
+        my.dy_archlist += my.arch.archlist
+
     if not opts.quiet: print 'setting up repos'
     for r in opts.old:
         if not opts.quiet: print "setting up old repo %s" % r
@@ -169,52 +214,84 @@ def main(args):
             print "Could not setup repo at url %s: %s" % (r, e)
             sys.exit(1)
     if not opts.quiet: print 'performing the diff'
-    ygh = my.dy_diff()
+    ygh = my.dy_diff(opts.compare_arch)
     
 
+
     total_sizechange = 0
     add_sizechange = 0
     remove_sizechange = 0
     if ygh.add:
         for pkg in sorted(ygh.add):
-            print 'New package %s' % pkg.name
-            print '        %s' % pkg.summary
+            if opts.compare_arch:
+                print 'New package: %s' % pkg
+            else:
+                print 'New package: %s-%s-%s' % (pkg.name, pkg.ver, pkg.rel)
+            print '             %s\n' % to_unicode(pkg.summary)
             add_sizechange += int(pkg.size)
                 
     if ygh.remove:
         for pkg in sorted(ygh.remove):
-            print 'Removed package %s' % pkg.name
-            if ygh.obsoleted.has_key(pkg):
-                print 'Obsoleted by %s' % ygh.obsoleted[pkg]
+            if opts.compare_arch:
+                print 'Removed package: %s' % pkg
+            else:
+                print 'Removed package:  %s-%s-%s' % (pkg.name, pkg.ver,pkg.rel)
+            if pkg in ygh.obsoleted:
+                print 'Obsoleted by   :  %s' % ygh.obsoleted[pkg]
             remove_sizechange += (int(pkg.size))
                 
     if ygh.modified:
-        print 'Updated Packages:\n'
+        print '\nUpdated Packages:\n'
         for (pkg, oldpkg) in sorted(ygh.modified):
-            msg = "%s-%s-%s" % (pkg.name, pkg.ver, pkg.rel)
-            dashes = "-" * len(msg) 
-            msg += "\n%s\n" % dashes
-            # get newest clog time from the oldpkg
-            # for any newer clog in pkg
-            # print it
-            oldlogs = oldpkg.changelog
-            oldlogs.sort()
-            oldlogs.reverse()
-            if len(oldlogs):
-                oldtime = oldlogs[0][0]
-                clogdelta = []
-                for (t, author, content) in  pkg.changelog:
-                    if t > oldtime:
-                        msg += "* %s %s\n%s\n\n" % (datetime.date.fromtimestamp(int(t)).strftime("%a %b %d %Y"),
-                               to_unicode(author), to_unicode(content))
             if opts.size:
                 sizechange = int(pkg.size) - int(oldpkg.size)
                 total_sizechange += sizechange
-                msg += "\nSize Change: %s bytes\n" % sizechange
+            
+            if opts.simple:
+                if opts.compare_arch:
+                    msg = "%s: %s ->  %s" % (pkg.name, oldpkg, pkg)
+                else:
+                    msg = "%s: %s-%s-%s ->  %s-%s-%s" % (pkg.name, oldpkg.name, 
+                                                         oldpkg.ver, oldpkg.rel,
+                                                         pkg.name, pkg.ver,
+                                                         pkg.rel)
+            else:
+                if opts.compare_arch:
+                    msg = "%s" % pkg
+                else:
+                    msg = "%s-%s-%s" % (pkg.name, pkg.ver, pkg.rel)
+                dashes = "-" * len(msg) 
+                msg += "\n%s\n" % dashes
+                # get newest clog time from the oldpkg
+                # for any newer clog in pkg
+                # print it
+                oldlogs = oldpkg.changelog
+                if len(oldlogs):
+                    #  Don't sort as that can screw the order up when time is the
+                    # same.
+                    oldtime    = oldlogs[0][0]
+                    oldauth    = oldlogs[0][1]
+                    oldcontent = oldlogs[0][2]
+                    for (t, author, content) in  pkg.changelog:
+                        if t < oldtime:
+                            break
+                        if ((t == oldtime) and (author == oldauth) and
+                            (content == oldcontent)):
+                            break
+                        tm = datetime.date.fromtimestamp(int(t))
+                        tm = tm.strftime("%a %b %d %Y")
+                        msg += "* %s %s\n%s\n\n" % (tm, to_unicode(author),
+                                                    to_unicode(content))
+                    if opts.size:
+                        msg += "\nSize Change: %s bytes\n" % sizechange
 
             print msg
 
-    print 'Summary:'
+    if (not ygh.add and not ygh.remove and not ygh.modified and
+        not my.pkgSack.searchNevra(arch='src')):
+        print "** No 'src' pkgs in any repo. maybe see docs. on --archlist?"
+
+    print '\nSummary:'
     print 'Added Packages: %s' % len(ygh.add)
     print 'Removed Packages: %s' % len(ygh.remove)
     print 'Modified Packages: %s' % len(ygh.modified)
