@@ -31,12 +31,6 @@ from yum import misc
 from optparse import OptionParser
 
 
-class Error(Exception):
-    def __init__(self, message=None):
-        Exception.__init__(self)
-        self.message = message
-
-
 def errorprint(stuff):
     print >> sys.stderr, stuff
     
@@ -49,8 +43,8 @@ def getFileList(path, ext, filelist):
     try:
         dir_list = os.listdir(path)
     except OSError, e:
-        errorprint('Error accessing directory %s, %s' % (path, e.message))
-        raise Error, 'Error accessing directory %s, %s' % (path, e.message)
+        errorprint('Error accessing directory %s, %s' % (path, str(e)))
+        return []
         
     for d in dir_list:
         if os.path.isdir(path + '/' + d):
@@ -158,11 +152,11 @@ def main(args):
         (n,a,e,v,r) = pkgtuple
         del hdr
         
-        if not pkgdict.has_key((n,a)):
+        if (n,a) not in pkgdict:
             pkgdict[(n,a)] = []
         pkgdict[(n,a)].append((e,v,r))
         
-        if not verfile.has_key(pkgtuple):
+        if pkgtuple not in verfile:
             verfile[pkgtuple] = []
         verfile[pkgtuple].append(pkg)
         
