@@ -73,7 +73,8 @@ class YumBuildDep(YumUtilBase):
 
         # turn of our local gpg checking for opening the srpm if it is turned
         # off for repos :)
-        if opts.nogpgcheck:
+        if (opts.nogpgcheck or
+            not self.conf.localpkg_gpgcheck or not self.conf.gpgcheck):
             self.ts.pushVSFlags((rpm._RPMVSF_NOSIGNATURES|rpm._RPMVSF_NODIGESTS))
 
         # Check if there is anything to do.
@@ -96,7 +97,17 @@ class YumBuildDep(YumUtilBase):
             self.logger.error(msg)
             sys.exit(1)
 
-        self.buildTransaction()
+        if hasattr(self, 'doUtilBuildTransaction'):
+            errc = self.doUtilBuildTransaction()
+            if errc:
+                sys.exit(errc)
+        else:
+            try:
+                self.buildTransaction()
+            except yum.Errors.YumBaseError, e:
+                self.logger.critical("Error building transaction: %s" % e)
+                sys.exit(1)
+
         if len(self.tsInfo) < 1:
             print 'No uninstalled build requires'
             sys.exit()
@@ -128,6 +139,24 @@ class YumBuildDep(YumUtilBase):
                     print "Could not setup repo %s: %s" % (r.id, e)
                     sys.exit(1)
 
+    def install_deps(self, deplist):
+        for dep in deplist:
+            self.logger.debug(' REQ:  %s' % dep)                
+            if dep.startswith("rpmlib("): 
+                continue
+            instreq = self.returnInstalledPackagesByDep(dep)
+            if instreq:
+                self.logger.info(' --> Already installed : %s'  % instreq[0])                    
+                continue
+            try:
+                pkg = self.returnPackageByDep(dep)
+                self.logger.info(' --> %s' % pkg)
+                self.install(pkg)
+                
+            except yum.Errors.YumBaseError, e:
+                self.logger.error("Error: %s" % e)
+                sys.exit(1)
+
     # go through each of the pkgs, figure out what they are/where they are 
     # if they are not a local package then run
         # Setup source repos
@@ -138,7 +167,14 @@ class YumBuildDep(YumUtilBase):
     
     def get_build_deps(self,opts):
         srcnames = []
+        specnames = []
         srpms = []
+        specworks = False
+
+        # See if we can use spec files for buildrequires
+        if hasattr(rpm, 'spec') and hasattr(rpm.spec, 'sourceHeader'):
+            specworks = True
+
         for arg in self.cmds:
             if arg.endswith('.src.rpm'):
                 try:
@@ -149,6 +185,8 @@ class YumBuildDep(YumUtilBase):
                     raise
             elif arg.endswith('.src'):
                 srcnames.append(arg)
+            elif specworks and arg.endswith('.spec'):
+                specnames.append(arg)
             else:
                 srcnames.append(arg)
 
@@ -175,25 +213,22 @@ class YumBuildDep(YumUtilBase):
 
         for srpm in toActOn:
             self.logger.info('Getting requirements for %s' % srpm)
-            for dep in srpm.requiresList():
-                self.logger.debug(' REQ:  %s' % dep)                
-                if dep.startswith("rpmlib("): 
-                    continue
-                instreq = self.returnInstalledPackagesByDep(dep)
-                if instreq:
-                    self.logger.info(' --> Already installed : %s'  % instreq[0])                    
-                    continue
-                try:
-                    pkg = self.returnPackageByDep(dep)
-                    self.logger.info(' --> %s' % pkg)
-                    if not self.rpmdb.installed(name=pkg.name):
-                        self.tsInfo.addInstall(pkg)
-                    
-                except yum.Errors.YumBaseError, e:
-                    self.logger.error("Error: %s" % e)
-                    sys.exit(1)
-    
+            self.install_deps(srpm.requiresList())
     
+        for name in specnames:
+            try:
+                spec = rpm.spec(name)
+            except ValueError:
+                self.logger.error("Bad spec: %s" % name)
+                continue
+
+            buildreqs = []
+            for d in rpm.ds(spec.sourceHeader, 'requires'):
+                buildreqs.append(d.DNEVR()[2:])
+                
+            self.logger.info('Getting requirements for %s' % name)
+            self.install_deps(buildreqs)
+            
 if __name__ == '__main__':
     setup_locale()
     util = YumBuildDep()
