@@ -161,6 +161,7 @@ class YumCompleteTransaction(YumUtilBase):
         # populate the ts
         # run it
 
+        self.run_with_package_names.add('yum-utils')
         times = []
         for thistime in find_unfinished_transactions(self.conf.persistdir):
             if thistime.endswith('disabled'):
@@ -184,7 +185,13 @@ class YumCompleteTransaction(YumUtilBase):
         timestamp = times[-1]
         print "There are %d outstanding transactions to complete. Finishing the most recent one" % len(times)
         
-        remaining = find_ts_remaining(timestamp, yumlibpath=self.conf.persistdir)
+        try:
+            remaining = find_ts_remaining(timestamp, yumlibpath=self.conf.persistdir)
+        except yum.Errors.MiscError, e:
+            self.logger.error("Error: %s" % e)
+            self.logger.error("Please report this error to: %s" % self.conf.bugtracker_url)
+            sys.exit(1)
+            
         print "The remaining transaction had %d elements left to run" % len(remaining)
         for (action, pkgspec) in remaining:
             if action == 'install':
@@ -200,7 +207,17 @@ class YumCompleteTransaction(YumUtilBase):
 
 
         current_count = len(self.tsInfo)
-        self.buildTransaction(unfinished_transactions_check=False)
+        if hasattr(self, 'doUtilBuildTransaction'):
+            errc = self.doUtilBuildTransaction(unfinished_transactions_check=False)
+            if errc:
+                sys.exit(errc)
+        else:
+            try:
+                self.buildTransaction(unfinished_transactions_check=False)
+            except yum.Errors.YumBaseError, e:
+                self.logger.critical("Error building transaction: %s" % e)
+                sys.exit(1)
+
         if current_count != len(self.tsInfo):
             print '\n\nTransaction size changed - this means we are not doing the\n' \
                   'same transaction as we were before. Aborting and disabling\n' \
@@ -220,14 +237,17 @@ class YumCompleteTransaction(YumUtilBase):
             sys.exit()
 
         else:
-            if self.doUtilTransaction() == 0:
-                print "Cleaning up completed transaction file"
-                self.clean_up_ts_files(timestamp, self.conf.persistdir)
-                sys.exit()
-            else:
-                print "Not removing old transaction files"
-                sys.exit()
-
+            try:
+                if self.doUtilTransaction() == 0:
+                    print "Cleaning up completed transaction file"
+                    self.clean_up_ts_files(timestamp, self.conf.persistdir)
+                    sys.exit()
+                else:
+                    print "Not removing old transaction files"
+                    sys.exit()
+            except yum.Errors.YumBaseError,e:
+                print "Error: %s" % str(e)
+                sys.exit(1)                
 
 
 
