@@ -40,7 +40,7 @@ class YumDebugDump(yum.YumBase):
 
     def parse_args(self):
         parser = OptionParser()
-        parser.set_usage("yum-debug-dump [options]")
+        parser.set_usage("yum-debug-dump [options] [filename]")
         parser.add_option("--norepos", action="store_true", default=False,
            help="do not attempt to dump the repository contents")
         self.opts, self.args = parser.parse_args()
@@ -91,6 +91,9 @@ class YumDebugDump(yum.YumBase):
         msg += "  python ver: %s\n" % sys.version.replace('\n', '')
         return msg
 
+# remove pylint false positive
+# Instance of 'DummyYumPlugins' has no '_plugins' member (but some types could not be inferred)
+# pylint: disable-msg=E1103
     def dump_yum_config_info(self):
         msg = "%%%%YUM INFO\n"
         msg += "  arch: %s\n" % self.conf.yumvar['arch']
@@ -100,6 +103,7 @@ class YumDebugDump(yum.YumBase):
         msg += "  enabled plugins: %s\n" % ",".join(self.plugins._plugins.keys())
         msg += "  global excludes: %s\n" % ",".join(self.conf.exclude)
         return msg
+# pylint: enable-msg=E1103
 
     # FIXME: This should use rpmdb.check_*()
     def dump_rpm_problems(self):
@@ -128,7 +132,7 @@ class YumDebugDump(yum.YumBase):
                 if req.startswith('rpmlib'): 
                     continue # ignore rpmlib deps
 
-                if not providers.has_key((req,rflags,ver)):
+                if (req,rflags,ver) not in providers:
                     resolve_sack = self.rpmdb.whatProvides(req,rflags,ver)
                 else:
                     resolve_sack = providers[(req,rflags,ver)]
@@ -197,12 +201,10 @@ def main():
         my.repos.setCache(0)
 
     filename = None
-    if len(sys.argv) > 1:
-        filename = sys.argv[1]
+    if my.args:
+        filename = my.args[0]
     fn = my.create_debug_file(fn=filename)
     print "Output written to: %s" % fn
 
 if __name__ == "__main__":
     main()
-
-
